@@ -43,10 +43,13 @@ struct string_entry {
 class KSycocaDictStringList : public QList<string_entry *>
 {
 public:
+    KSycocaDictStringList() { }
     ~KSycocaDictStringList()
     {
         qDeleteAll(*this);
     }
+    KSycocaDictStringList(const KSycocaDictStringList &) = delete;
+    KSycocaDictStringList& operator=(const KSycocaDictStringList &) = delete;
 };
 
 class KSycocaDictPrivate
@@ -511,7 +514,7 @@ KSycocaDict::save(QDataStream &str)
 
                 /*qCDebug(SYCOCA) << QString("Duplicate lists: Offset = %1 list_size = %2")                           .arg(hashTable[i].duplicate_offset,8,16).arg(dups->count());
                 */
-                Q_FOREACH (string_entry* dup, *dups) {
+                for (string_entry* dup : qAsConst(*dups)) {
                     const qint32 offset = dup->payload->offset();
                     if (!offset) {
                         const QString storageId = dup->payload->storageId();
